Trait schemadb::schema::KeyCodec[][src]

pub trait KeyCodec<S: Schema + ?Sized>: Sized + PartialEq + Debug {
    fn encode_key(&self) -> Result<Vec<u8>>;
fn decode_key(data: &[u8]) -> Result<Self>; }
This trait defines a type that can serve as a Schema::Key.

Required methods

Converts self to bytes to be stored in DB.

Converts bytes fetched from DB to Self.

Implementors