Trait schemadb::schema::SeekKeyCodec [−][src]
This defines a type that can be used to seek a SchemaIterator, via
interfaces like seek.
Required methods
fn encode_seek_key(&self) -> Result<Vec<u8>>
fn encode_seek_key(&self) -> Result<Vec<u8>>
Converts self to bytes which is used to seek the underlying raw iterator.
Implementors
All keys can automatically be used as seek keys.